import requests
from datetime import datetime

class Tweet:
	def __init__(self, id):
		self.id = id
		try:
			self.__data= requests.get("https://cdn.syndication.twimg.com/tweet-result?id="+str(id)).json()
		except:
			self.__data=dict()
		self.__dict__.update(self.__data)
		if 'created_at' in self.__data.keys():
			self.created_at = datetime.strptime(self.created_at,'%Y-%m-%dT%H:%M:%S.%fZ')
		if 'user' in self.__data.keys():
			self.user = User(self.user)
		if 'parent' in self.__data.keys():
			self.parent = Parent(self.parent)
		if 'entities' in self.__data.keys():
			self.entities = Entities(self.entities)
		
	def __str__(self):
		return f"tweet id: {self.id}"


class User:
	def __init__(self, data):
		try:
			self.__data= data
		except:
			self.__data=dict()
		self.__dict__.update(self.__data)

class Parent:
	def __init__(self, data):
		try:
			self.__data= data
		except:
			self.__data=dict()
		self.__dict__.update(self.__data)
		if 'created_at' in self.__data.keys():
			self.created_at = datetime.strptime(self.created_at,'%Y-%m-%dT%H:%M:%S.%fZ')
		if 'user' in self.__data.keys():
			self.user = User(self.user)
		if 'entities' in self.__data.keys():
			self.entities = Entities(self.entities)

class Entities:
	def __init__(self, data):
		try:
			self.__data= data
		except:
			self.__data=dict()		
		self.__dict__.update(self.__data)
		





from setuptools import find_packages, setup
from os.path import join, dirname

with open(join(dirname(__file__),"README.md"),'r') as f:
    long_description =f.read()

setup(
	name='tweetpy',
	packages=find_packages(),
	author_email="<abderrahmane@elhellal.com>",
	url="https://tweetpy.elhellal.com/",
	project_urls = {
	  'Homepage': 'https://tweetpy.elhellal.com/',
	  'Source': 'https://github.com/abdouhl/tweetpy/',
	  'Documentation':'https://tweetpy.elhellal.com#doc'
	},
	version='1.0.4',
	description='Python package that allows to access the Tweet data without API',
	long_description_content_type="text/markdown",
	long_description=long_description,
	keywords=['twitter', 'tweets', 'tweet', 'twitter_scraper', 'twitter_sentiment', 'status'],
	author='abdouhl',
	license='MIT',
)
